@@ -30,7 +30,7 @@ class GeneralOptionsPage : public SettingsPage
 
     public:
 
-    explicit GeneralOptionsPage(QWidget *parent = 0);
+    explicit GeneralOptionsPage(QWidget *parent = nullptr);
 
     public slots:
 
@@ -43,10 +43,10 @@ class GeneralOptionsPage : public SettingsPage
 
     private:
 
-    QCheckBox *mUseLastSaveAction;
     QCheckBox *mRememberRect;
     QCheckBox *mUseLightBackground;
     QCheckBox *mCopyPathToClipboard;
+    QCheckBox *mShowMagnifier;
 };
 
 #endif // GENERALOPTIONSPAGE_H
