@@ -53,8 +53,6 @@ int main(int argc, char **argv)
     // set up the command line options parser
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
 
     parser.addOptions({
@@ -131,6 +129,7 @@ int main(int argc, char **argv)
 
     case SpectacleCore::DBusMode:
         app.setQuitOnLastWindowClosed(false);
+        break;
     case SpectacleCore::GuiMode:
         break;
     }
